"""
.. currentmodule:: flytekitplugins.kftensorflow

This package contains things that are useful when extending Flytekit.

.. autosummary::
   :template: custom.rst
   :toctree: generated/

   TfJob
"""

from .task import TfJob
